@@ -60,7 +60,7 @@ void setuptree(ControlTree *tree, ControlTree *parent, ControlTree *children,
 	tree->colour=colour;
 }
 
-ControlTree* gettree() {
+ControlTree* gettree() {	
 #ifdef GNOME_A11Y
   building=TRUE;
   menutree = new ControlTree;
@@ -73,15 +73,14 @@ ControlTree* gettree() {
   desktop = SPI_getDesktop(0);
 
   /* Paneltree
-                   /-menutree
+         |         /-menutree
      Widgettree------buttontree
                    \-edittree
-     Windowtree
   */
 
-  setuptree(paneltree, NULL, NULL, windowtree, NULL, 0, _("Panels"), -1);
-  setuptree(windowtree, NULL, NULL, widgettree, NULL, 0, _("Windows"), -1);
-  setuptree(widgettree, NULL, menutree, windowtree, NULL, 0, _("Application"),
+  /* Tree, parent, children, next, pointer, data, string, colour */
+  setuptree(paneltree, NULL, NULL, widgettree, NULL, 0, _("Panels"), -1);
+  setuptree(widgettree, NULL, menutree, NULL, NULL, 0, _("Application"),
 	    -1);
   setuptree(menutree, widgettree, NULL, buttontree, NULL, 0, _("Menus"), -1);
   setuptree(buttontree, NULL, NULL, edittree, NULL, 0, _("Buttons"), -1);
@@ -95,7 +94,7 @@ ControlTree* gettree() {
     }
   }
 
-  windowtree->children = buildwindowtree();
+  widgettree->children = menutree;
   
   if (focusedwindow!=NULL) {
     buildmenutree(focusedwindow,menutree,menus);
@@ -105,7 +104,6 @@ ControlTree* gettree() {
     widgettree->next=buildcontroltree();
   } else {
     widgettree=buildcontroltree();
-    windowtree->next=widgettree;
   }
 #else
   widgettree=buildcontroltree();
@@ -145,6 +143,7 @@ gboolean findpanels(Accessible *parent) {
 ControlTree* buildcontroltree() {
   dummy=new ControlTree;
   stoptree=new ControlTree;
+  windowtree = new ControlTree;
   ControlTree *pausetree=new ControlTree;
   ControlTree *movetree=new ControlTree;
   ControlTree *deletetree=new ControlTree;
@@ -154,7 +153,7 @@ ControlTree* buildcontroltree() {
 #ifndef GNOME_A11Y
   // Otherwise menutree hasn't been set yet, and we end up with a bunch of
   // null pointers rather than children
-  menutree=stoptree;
+  menutree=windowtree;
 #endif
   dummy->pointer=NULL;
   dummy->data=0;
@@ -162,12 +161,21 @@ ControlTree* buildcontroltree() {
   dummy->children=menutree;
   dummy->text=_("Control");
   dummy->colour=8;
+
+  windowtree->pointer=NULL;
+  windowtree->data=0;
+  windowtree->children=buildwindowtree();
+  windowtree->text=_("Windows");
+  windowtree->colour=-1;
+  windowtree->next=stoptree;
+
   stoptree->pointer=(void*)1;
   stoptree->data=2;
   stoptree->children=dummy;
   stoptree->text=_("Stop");
   stoptree->next=pausetree;
   stoptree->colour=242;
+
   pausetree->pointer=(void*)1;
   pausetree->data=3;
   pausetree->children=dummy;
@@ -211,7 +219,7 @@ ControlTree* buildcontroltree() {
 } else {
     pausetree->next=NULL;
 }
-  return stoptree;
+  return windowtree;
 }
 
 ControlTree* buildmovetree(ControlTree *movetree) {
@@ -436,14 +444,25 @@ ControlTree* buildwindowtree()
 	WnckWindow *window;
 	std::string name;
 	GList *windows = wnck_screen_get_windows(wnckscreen);
-		
+
 	for (l = windows; l; l = l->next) {
 		window = (WnckWindow*)l->data;
 		name = wnck_window_get_name (window);
-		tmptree->next = new ControlTree;
-		tmptree = tmptree->next;
 		setuptree(tmptree, NULL, controltree, NULL, (void *)window, 31, name, -1);
+		tmptree->next = new ControlTree;
+		tmptree->next->parent = tmptree;
+		tmptree = tmptree->next;
+
 	}
+	
+	if (tmptree->parent == NULL) {
+	  /* wnck didn't provide us with any windows */
+	  delete tmptree;
+	  return NULL;
+	}
+
+	tmptree->parent->next = NULL;
+	delete tmptree;
 	return firstchild;
 }
 
